/*
    qtZenOscillo : Software for using DSO-2020 usb scope under Linux
    Copyright (C) 2015 Olivier Poitevin

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Contact : code@zener.fr

*/

#ifndef SCOPEVIEW_H
#define SCOPEVIEW_H

#include <QWidget>
#include <QMouseEvent>
#include "datathread.h"

namespace Ui {
class ScopeView;
}

class ScopeView : public QWidget
{
    Q_OBJECT

public:
    explicit ScopeView(QWidget *parent = 0);
    ~ScopeView();
    bool ToggleRun(bool state);
    QVector<double> chan1Points;
    QVector<double> chan2Points;

    void setSpeed(int mantissa,int unit);
    void setCh1Activated(bool value);
    void setCh2Activated(bool value);
    void setCh1Range(int mV);
    void setCh2Range(int mV);
    void setFastMode(bool value);
    void setTrigChan(int chan);
    void setTrigValue(double val);
    void setEdgeType(bool isFalling);
    void setTrigFilter(bool state);
    void setCh1Offset(double val);
    void setCh2Offset(double val);

private slots:
    void getData(QVector<double> chan1,QVector<double> chan2,int nbToDisplay);

private:
    Ui::ScopeView *ui;
    void paintEvent(QPaintEvent*);
    void mousePressEvent(QMouseEvent * event);
    void mouseMoveEvent(QMouseEvent * event);
    void drawGrid(QPainter &p,int left,int top,int right,int bottom);
    void drawChannel(QPainter &p,int chanNum,enum Qt::GlobalColor pen,int sampleOffset,int left,int top,int width,int height,QVector<double>&Dat);
    DataThread dThread;
    bool ch1Activated; // true if ch1 Activated
    bool ch2Activated; // true if ch2 Activated
    bool fastMode;
    int trigChan; // 1 or 2
    double trigValue;
    int nbSamplesToDisplay;
    bool trigFallingEdge;
    bool trigFiltered;
    double ch1Offset;
    double ch2Offset;
    int lastMouseX;
    int viewOffset;
    int speedM;
    int speedU;
};

#endif // SCOPEVIEW_H
